using System;
using System.Collections.Generic;
using System.Data;
using DataBinding.Domain;

namespace DataBinding.DataAccess.Mappers
{
    public class CustomerMapper
    {
        const string ALL_CUSTOMERS_SQL = "SELECT * FROM Customers";
        
        public IList<Customer> GetAllCustomers()
        {                        
            DataTable results = new DatabaseGateway().QueryForDataTable(ALL_CUSTOMERS_SQL);            
            return CreateListOfCustomersFrom(results);
        }

        private IList<Customer> CreateListOfCustomersFrom(DataTable results)
        {
            IList<Customer> customers = new List<Customer>();
            
            foreach (DataRow customerRow in results.Rows)
            {
                customers.Add(CreateCustomerFrom(customerRow));    
            }
            
            return customers;
        }

        private Customer CreateCustomerFrom(DataRow row)
        {
            return new Customer(row[Columns.COMPANY_NAME].ToString(), row[Columns.CONTACT_NAME].ToString(), row[Columns.CONTACT_TITLE].ToString(), row[Columns.ADDRESS].ToString(), row[Columns.CITY].ToString(), row[Columns.REGION].ToString(), row[Columns.POSTAL_CODE].ToString(), row[Columns.COUNTRY].ToString(), row[Columns.PHONE].ToString(), row[Columns.FAX].ToString());
        }
        
        private abstract class Columns
        {                   
            public const string COMPANY_NAME = "CompanyName";
            public const string CONTACT_NAME = "ContactName";
            public const string CONTACT_TITLE = "ContactTitle";
            public const string ADDRESS = "Address";
            public const string CITY = "City";
            public const string REGION = "Region";
            public const string POSTAL_CODE = "PostalCode";
            public const string COUNTRY = "Country";
            public const string PHONE = "Phone";
            public const string FAX = "Fax";
            
            private Columns()
            {
            }     
        }
    }
}